"use strict";
(self["webpackChunk_JUPYTERLAB_CORE_OUTPUT"] = self["webpackChunk_JUPYTERLAB_CORE_OUTPUT"] || []).push([["8558"], {
69181(__unused_rspack_module, __webpack_exports__, __webpack_require__) {
__webpack_require__.d(__webpack_exports__, {
  createArchitectureServices: () => (/* reexport safe */ _chunk_O7ZBX7Z2_mjs__rspack_import_0.S)
});
/* import */ var _chunk_O7ZBX7Z2_mjs__rspack_import_0 = __webpack_require__(35977);
/* import */ var _chunk_FPAJGGOC_mjs__rspack_import_1 = __webpack_require__(38631);





},

}]);
//# sourceMappingURL=8558.65ae94e77cd37ed1.js.map?v=65ae94e77cd37ed1