"use strict";
(self["webpackChunk_JUPYTERLAB_CORE_OUTPUT"] = self["webpackChunk_JUPYTERLAB_CORE_OUTPUT"] || []).push([["1479"], {
79146(__unused_rspack_module, __webpack_exports__, __webpack_require__) {
__webpack_require__.d(__webpack_exports__, {
  createPacketServices: () => (/* reexport safe */ _chunk_76Q3JFCE_mjs__rspack_import_0.$)
});
/* import */ var _chunk_76Q3JFCE_mjs__rspack_import_0 = __webpack_require__(18759);
/* import */ var _chunk_FPAJGGOC_mjs__rspack_import_1 = __webpack_require__(38631);





},

}]);
//# sourceMappingURL=1479.f427d62bd1c0646c.js.map?v=f427d62bd1c0646c