"use strict";
(self["webpackChunk_JUPYTERLAB_CORE_OUTPUT"] = self["webpackChunk_JUPYTERLAB_CORE_OUTPUT"] || []).push([["9832"], {
57302(__unused_rspack_module, __webpack_exports__, __webpack_require__) {
__webpack_require__.d(__webpack_exports__, {
  createGitGraphServices: () => (/* reexport safe */ _chunk_S6J4BHB3_mjs__rspack_import_0.b)
});
/* import */ var _chunk_S6J4BHB3_mjs__rspack_import_0 = __webpack_require__(78362);
/* import */ var _chunk_FPAJGGOC_mjs__rspack_import_1 = __webpack_require__(38631);





},

}]);
//# sourceMappingURL=9832.e3640dfd64066f1f.js.map?v=e3640dfd64066f1f